@@ -1,5 +1,7 @@
 #' Downloads and reads Lattes data based on a vector of Lattes ids
 #'
+#' DEPRECATED. Please use function gld_get_lattes_data_from_zip to read the files
+#'
 #' This function downloads xml data directly from Lattes and reads the resulting file, giving as output three dataframes
 #' , a table with description of researchers, list of all publications and a table with completed supervisions
 #'
@@ -27,7 +29,6 @@ gld_get_lattes_data <- function(id.vec,
                                 field.qualis = NULL,
                                 folder.dl = tempdir()) {
 
-
 #   my.message <- paste0('\n\n:(\n\nSadly, the Lattes address where the xml files were found and downloaded ',
 # 'without a captcha wall is not online for a couple of weeks now.  Difficult to say why is that. ',
 # 'I hope, and will keep track of, if a new site is published.',
@@ -39,6 +40,17 @@ gld_get_lattes_data <- function(id.vec,
 #   cat('\n\nReturning an empty dataframe..')
 #   return(data.frame())
 
+  # deprecations message
+  my.message <- paste0('Function gld_get_lattes_data is deprecated.',
+                       '\n\nDue to changes in lattes website, the automatic download of xml files no longer works without captcha. ',
+                       '\nIn order to use the package, you must  download the xml zip files individually (see XML button on top right of lattes page) and use ',
+                       'function gld_get_lattes_data_from_zip to read all the data',
+                       '\n\nExiting Now..')
+
+  cat(my.message)
+
+  return(FALSE)
+
   # check args
   id.vec <- as.character(id.vec)
   n.char <- nchar(id.vec)
